﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using HeuristicLab.Collections;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Analysis {
  [Item("Histogram", "Holds data that is to be displayed as a histogram.")]
  [StorableClass]
  public class Histogram : NamedItem {

    private ObservableCollection<double> values;
    public ObservableCollection<double> Values {
      get { return values; }
    }

    [Storable(Name = "values")]
    private IEnumerable<double> StorableValues {
      get { return values; }
      set { values = new ObservableCollection<double>(value); }
    }

    [StorableConstructor]
    protected Histogram(bool deserializing) : base(deserializing) { }
    protected Histogram(Histogram original, Cloner cloner)
      : base(original, cloner) {
      this.values = new ObservableCollection<double>(original.values);
    }
    public Histogram()
      : base() {
      values = new ObservableCollection<double>();
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new Histogram(this, cloner);
    }
  }
}
